@@ -108,10 +108,10 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     m_vertSplitter = new QSplitter(Qt::Vertical, this);
 
 
-    QWidget* topicWidget = new QWidget(m_vertSplitter);
+    auto* topicWidget = new QWidget(m_vertSplitter);
     m_vertSplitter->setStretchFactor(m_vertSplitter->indexOf(topicWidget), 0);
 
-    QGridLayout* topicLayout = new QGridLayout(topicWidget);
+    auto* topicLayout = new QGridLayout(topicWidget);
     topicLayout->setContentsMargins(0, 0, 0, 0);
     topicLayout->setSpacing(0);
 
@@ -137,7 +137,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
 
     // The box holding the channel modes
     modeBox = new QFrame(topicWidget);
-    QHBoxLayout* modeBoxLayout = new QHBoxLayout(modeBox);
+    auto* modeBoxLayout = new QHBoxLayout(modeBox);
     modeBoxLayout->setContentsMargins(0, 0, 0, 0);
     modeBox->hide();
     modeBox->setSizePolicy(hfixed);
@@ -196,7 +196,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     m_vertSplitter->setStretchFactor(m_vertSplitter->indexOf(m_horizSplitter), 1);
 
     // Server will be set later in setServer()
-    IRCViewBox* ircViewBox = new IRCViewBox(m_horizSplitter);
+    auto* ircViewBox = new IRCViewBox(m_horizSplitter);
     m_horizSplitter->setStretchFactor(m_horizSplitter->indexOf(ircViewBox), 1);
     setTextView(ircViewBox->ircView());
     ircViewBox->ircView()->setContextMenuOptions(IrcContextMenus::ShowChannelActions, true);
@@ -204,7 +204,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
     // The box that holds the Nick List and the quick action buttons
     nickListButtons = new QFrame(m_horizSplitter);
     m_horizSplitter->setStretchFactor(m_horizSplitter->indexOf(nickListButtons), 0);
-    QVBoxLayout* nickListButtonsLayout = new QVBoxLayout(nickListButtons);
+    auto* nickListButtonsLayout = new QVBoxLayout(nickListButtons);
     nickListButtonsLayout->setSpacing(0);
     nickListButtonsLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -217,7 +217,7 @@ Channel::Channel(QWidget* parent, const QString& _name) : ChatWindow(parent)
 
     // The box holding the Nickname button and Channel input
     commandLineBox = new QFrame(this);
-    QHBoxLayout* commandLineLayout = new QHBoxLayout(commandLineBox);
+    auto* commandLineLayout = new QHBoxLayout(commandLineBox);
     commandLineBox->setLayout(commandLineLayout);
     commandLineLayout->setContentsMargins(0, 0, 0, 0);
     commandLineLayout->setSpacing(spacing());
@@ -769,7 +769,7 @@ Konversation::ChannelSettings Channel::channelSettings() const
 
 void Channel::sendFileMenu()
 {
-    emit sendFile();
+    Q_EMIT sendFile();
 }
 
 void Channel::channelTextEntered()
@@ -1088,7 +1088,7 @@ void Channel::joinNickname(ChannelNickPtr channelNick, const QHash<QString, QStr
     if(channelNick->getNickname() == m_server->getNickname())
     {
         m_joined = true;
-        emit joined(this);
+        Q_EMIT joined(this);
         if (displayCommandMessage)
             appendCommandMessage(i18nc("Message type", "Join"), i18nc("%1 = our hostmask, %2 = channel",
                                  "You (%1) have joined the channel %2.", channelNick->getHostmask(), getName()), messageTags, false, true);
@@ -1350,7 +1350,7 @@ void Channel::emitUpdateInfo()
     info += i18np("%1 nick", "%1 nicks", numberOfNicks());
     info += i18np(" (%1 op)", " (%1 ops)", numberOfOps());
 
-    emit updateInfo(info);
+    Q_EMIT updateInfo(info);
 }
 
 QString Channel::getTopic() const
@@ -1847,33 +1847,33 @@ void Channel::clearModeList()
 
     if (!k.isEmpty()) m_modeList << k;
 
-    modeT->setOn(0);
-    modeT->setDown(0);
+    modeT->setOn(false);
+    modeT->setDown(false);
 
-    modeN->setOn(0);
-    modeN->setDown(0);
+    modeN->setOn(false);
+    modeN->setDown(false);
 
-    modeS->setOn(0);
-    modeS->setDown(0);
+    modeS->setOn(false);
+    modeS->setDown(false);
 
-    modeI->setOn(0);
-    modeI->setDown(0);
+    modeI->setOn(false);
+    modeI->setDown(false);
 
-    modeP->setOn(0);
-    modeP->setDown(0);
+    modeP->setOn(false);
+    modeP->setDown(false);
 
-    modeM->setOn(0);
-    modeM->setDown(0);
+    modeM->setOn(false);
+    modeM->setDown(false);
 
-    modeK->setOn(0);
-    modeK->setDown(0);
+    modeK->setOn(false);
+    modeK->setDown(false);
 
-    modeL->setOn(0);
-    modeL->setDown(0);
+    modeL->setOn(false);
+    modeL->setDown(false);
 
     limit->clear();
 
-    emit modesChanged();
+    Q_EMIT modesChanged();
 }
 
 void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
@@ -1907,7 +1907,7 @@ void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
             m_modeList.removeOne(mode);
         }
     }
-    emit modesChanged();
+    Q_EMIT modesChanged();
 }
 
 void Channel::updateQuickButtons()
@@ -1919,7 +1919,7 @@ void Channel::updateQuickButtons()
     m_buttonsGrid = new QWidget (nickListButtons); //Q3Grid(2, nickListButtons);
     nickListButtons->layout()->addWidget(m_buttonsGrid);
     m_buttonsGrid->hide();
-    QGridLayout* layout = new QGridLayout (m_buttonsGrid);
+    auto* layout = new QGridLayout (m_buttonsGrid);
     layout->setContentsMargins(0, 0, 0, 0);
 
     int col = 0;
@@ -1931,7 +1931,7 @@ void Channel::updateQuickButtons()
     for(int index=0;index<newButtonList.count();index++)
     {
         // generate empty buttons first, text will be added later
-        QuickButton* quickButton = new QuickButton(QString(), QString(), m_buttonsGrid);
+        auto* quickButton = new QuickButton(QString(), QString(), m_buttonsGrid);
         col = index % 2;
         layout->addWidget (quickButton, row, col);
         row += col;
@@ -2673,7 +2673,7 @@ void Channel::addBan(const QString& ban)
             // Ban is already in list.
             it = m_BanList.erase(it);
 
-            emit banRemoved(ban.section(QLatin1Char(' '), 0, 0));
+            Q_EMIT banRemoved(ban.section(QLatin1Char(' '), 0, 0));
         } else {
             ++it;
         }
@@ -2681,7 +2681,7 @@ void Channel::addBan(const QString& ban)
 
     m_BanList.prepend(ban);
 
-    emit banAdded(ban);
+    Q_EMIT banAdded(ban);
 }
 
 void Channel::removeBan(const QString& ban)
@@ -2692,7 +2692,7 @@ void Channel::removeBan(const QString& ban)
     {
       m_BanList.removeOne(string);
 
-      emit banRemoved(ban);
+      Q_EMIT banRemoved(ban);
     }
   }
 }
@@ -2701,7 +2701,7 @@ void Channel::clearBanList()
 {
   m_BanList.clear();
 
-  emit banListCleared();
+  Q_EMIT banListCleared();
 }
 
 void Channel::append(const QString& nickname, const QString& message, const QHash<QString, QString> &messageTags, const QString& label)
